You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@falcon.apache.org by sr...@apache.org on 2013/07/23 03:37:20 UTC

[1/8] git commit: FALCON-56 Update Falcon packing to include all source files. Contributed by Srikanth Sundarrajan

Updated Branches:
  refs/heads/master caa0d26b9 -> 9f3c4d9ec
  refs/heads/v0.3 c823ce175 -> 5b5a5ce43


FALCON-56 Update Falcon packing to include all source files. Contributed by Srikanth Sundarrajan


Project: http://git-wip-us.apache.org/repos/asf/incubator-falcon/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-falcon/commit/54d827f2
Tree: http://git-wip-us.apache.org/repos/asf/incubator-falcon/tree/54d827f2
Diff: http://git-wip-us.apache.org/repos/asf/incubator-falcon/diff/54d827f2

Branch: refs/heads/v0.3
Commit: 54d827f29a2c21deb254cd51f95bccaba16ce844
Parents: c823ce1
Author: srikanth.sundarrajan <sr...@inmobi.com>
Authored: Mon Jul 22 19:06:05 2013 +0530
Committer: srikanth.sundarrajan <sr...@inmobi.com>
Committed: Mon Jul 22 19:06:05 2013 +0530

----------------------------------------------------------------------
 pom.xml                             |  1 +
 src/main/assemblies/package.xml     | 18 +--------------
 src/main/assemblies/src-package.xml | 38 ++++++++++++++++++++++++++++++++
 3 files changed, 40 insertions(+), 17 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/54d827f2/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index 37a50be..51b1eef 100644
--- a/pom.xml
+++ b/pom.xml
@@ -769,6 +769,7 @@
                 <configuration>
                     <descriptors>
                         <descriptor>src/main/assemblies/package.xml</descriptor>
+                        <descriptor>src/main/assemblies/src-package.xml</descriptor>
                     </descriptors>
                     <finalName>falcon-${project.version}</finalName>
                 </configuration>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/54d827f2/src/main/assemblies/package.xml
----------------------------------------------------------------------
diff --git a/src/main/assemblies/package.xml b/src/main/assemblies/package.xml
index fd600f2..b68692b 100644
--- a/src/main/assemblies/package.xml
+++ b/src/main/assemblies/package.xml
@@ -20,9 +20,9 @@
     xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
     xsi:schemaLocation="http://maven.apache.org/plugins/maven-assembly-plugin/assembly/1.1.2 http://maven.apache.org/xsd/assembly-1.1.2.xsd">
     <formats>
-        <format>dir</format>
         <format>tar.gz</format>
     </formats>
+    <id>bin</id>
     <fileSets>
         <fileSet>
             <directory>src/conf/</directory>
@@ -35,22 +35,6 @@
         </fileSet>
 
         <fileSet>
-            <directory>.</directory>
-            <outputDirectory>src</outputDirectory>
-            <includes>
-                <include>**/target/*sources.jar</include>
-            </includes>
-        </fileSet>
-
-        <fileSet>
-            <directory>.</directory>
-            <outputDirectory>docs</outputDirectory>
-            <includes>
-                <include>**/target/*javadoc.jar</include>
-            </includes>
-        </fileSet>
-
-        <fileSet>
             <directory>client/target/dependency</directory>
             <outputDirectory>client/lib</outputDirectory>
         </fileSet>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/54d827f2/src/main/assemblies/src-package.xml
----------------------------------------------------------------------
diff --git a/src/main/assemblies/src-package.xml b/src/main/assemblies/src-package.xml
new file mode 100644
index 0000000..bdcf464
--- /dev/null
+++ b/src/main/assemblies/src-package.xml
@@ -0,0 +1,38 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!--
+  Licensed to the Apache Software Foundation (ASF) under one
+  or more contributor license agreements.  See the NOTICE file
+  distributed with this work for additional information
+  regarding copyright ownership.  The ASF licenses this file
+  to you under the Apache License, Version 2.0 (the
+  "License"); you may not use this file except in compliance
+  with the License.  You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+  Unless required by applicable law or agreed to in writing, software
+  distributed under the License is distributed on an "AS IS" BASIS,
+  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+  See the License for the specific language governing permissions and
+  limitations under the License.
+-->
+<assembly xmlns="http://maven.apache.org/plugins/maven-assembly-plugin/assembly/1.1.2"
+    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+    xsi:schemaLocation="http://maven.apache.org/plugins/maven-assembly-plugin/assembly/1.1.2 http://maven.apache.org/xsd/assembly-1.1.2.xsd">
+    <formats>
+        <format>tar.gz</format>
+    </formats>
+    <id>sources</id>
+    <fileSets>
+        <fileSet>
+            <directory>.</directory>
+            <excludes>
+                <exclude>**/target/**</exclude>
+                <exclude>**/logs/**</exclude>
+                <exclude>**/activemq-data/**</exclude>
+                <exclude>**/.git/**</exclude>
+            </excludes>
+        </fileSet>
+    </fileSets>
+</assembly>
+    


[7/8] git commit: FALCON-57 Build fails if the source is not in scm. Contributed by Srikanth Sundarrajan

Posted by sr...@apache.org.
FALCON-57 Build fails if the source is not in scm. Contributed by Srikanth Sundarrajan


Project: http://git-wip-us.apache.org/repos/asf/incubator-falcon/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-falcon/commit/5b5a5ce4
Tree: http://git-wip-us.apache.org/repos/asf/incubator-falcon/tree/5b5a5ce4
Diff: http://git-wip-us.apache.org/repos/asf/incubator-falcon/diff/5b5a5ce4

Branch: refs/heads/v0.3
Commit: 5b5a5ce430882d858847ece8561e7fe7201e5d9a
Parents: 812f6f7
Author: srikanth.sundarrajan <sr...@inmobi.com>
Authored: Mon Jul 22 21:10:27 2013 +0530
Committer: srikanth.sundarrajan <sr...@inmobi.com>
Committed: Mon Jul 22 21:10:27 2013 +0530

----------------------------------------------------------------------
 CHANGES.txt | 2 ++
 pom.xml     | 1 +
 2 files changed, 3 insertions(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/5b5a5ce4/CHANGES.txt
----------------------------------------------------------------------
diff --git a/CHANGES.txt b/CHANGES.txt
index 8f75c6d..0e04286 100755
--- a/CHANGES.txt
+++ b/CHANGES.txt
@@ -8,6 +8,8 @@ Release Version: 0.3
 
   IMPROVEMENTS
    
+    FALCON-57 Build fails if the source is not in scm. (Srikanth Sundarrajan)
+
     FALCON-53 Add -incubating to the version. (Jarek Jarcec Cecho via Srikanth
     Sundarrajan)
 

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/5b5a5ce4/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index 8fbce7b..39004ab 100644
--- a/pom.xml
+++ b/pom.xml
@@ -717,6 +717,7 @@
                     </execution>
                 </executions>
                 <configuration>
+                    <revisionOnScmFailure>release</revisionOnScmFailure>
                     <doCheck>false</doCheck>
                     <doUpdate>false</doUpdate>
                 </configuration>


[5/8] git commit: FALCON-53 Add -incubating to the version. Contributed by Jarek Jarcec Cecho

Posted by sr...@apache.org.
FALCON-53 Add -incubating to the version. Contributed by Jarek Jarcec Cecho


Project: http://git-wip-us.apache.org/repos/asf/incubator-falcon/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-falcon/commit/24edc18b
Tree: http://git-wip-us.apache.org/repos/asf/incubator-falcon/tree/24edc18b
Diff: http://git-wip-us.apache.org/repos/asf/incubator-falcon/diff/24edc18b

Branch: refs/heads/master
Commit: 24edc18b39e752ac25db697dcc51b30a3f80ce03
Parents: 3010298
Author: srikanth.sundarrajan <sr...@inmobi.com>
Authored: Mon Jul 22 19:15:53 2013 +0530
Committer: srikanth.sundarrajan <sr...@inmobi.com>
Committed: Mon Jul 22 19:15:53 2013 +0530

----------------------------------------------------------------------
 CHANGES.txt                 | 3 +++
 acquisition/pom.xml         | 2 +-
 archival/pom.xml            | 2 +-
 build-tools/pom.xml         | 2 +-
 client/pom.xml              | 2 +-
 common/pom.xml              | 2 +-
 docs/pom.xml                | 2 +-
 feed/pom.xml                | 2 +-
 hadoop-webapp/pom.xml       | 2 +-
 messaging/pom.xml           | 2 +-
 metrics/pom.xml             | 2 +-
 oozie-el-extensions/pom.xml | 2 +-
 oozie/pom.xml               | 2 +-
 pom.xml                     | 4 ++--
 prism/pom.xml               | 2 +-
 process/pom.xml             | 2 +-
 replication/pom.xml         | 2 +-
 rerun/pom.xml               | 2 +-
 retention/pom.xml           | 2 +-
 test-util/pom.xml           | 2 +-
 webapp/pom.xml              | 2 +-
 21 files changed, 24 insertions(+), 21 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/CHANGES.txt
----------------------------------------------------------------------
diff --git a/CHANGES.txt b/CHANGES.txt
index 33cc31f..234eee6 100755
--- a/CHANGES.txt
+++ b/CHANGES.txt
@@ -14,6 +14,9 @@ Trunk (Unreleased)
 
 Release Version: 0.3
 
+    FALCON-53 Add -incubating to the version. (Jarek Jarcec Cecho via Srikanth
+    Sundarrajan)
+
     FALCON-56 Update Falcon packing to include all source files. (Srikanth
     Sundarrajan)
 

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/acquisition/pom.xml
----------------------------------------------------------------------
diff --git a/acquisition/pom.xml b/acquisition/pom.xml
index 233719c..9d060ab 100644
--- a/acquisition/pom.xml
+++ b/acquisition/pom.xml
@@ -24,7 +24,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-acquisition</artifactId>
     <description>Apache Falcon Acquisition Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/archival/pom.xml
----------------------------------------------------------------------
diff --git a/archival/pom.xml b/archival/pom.xml
index 02a26b6..0b99bbb 100644
--- a/archival/pom.xml
+++ b/archival/pom.xml
@@ -24,7 +24,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-archival</artifactId>
     <description>Apache Falcon Archival Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/build-tools/pom.xml
----------------------------------------------------------------------
diff --git a/build-tools/pom.xml b/build-tools/pom.xml
index 5b55268..ba8f758 100644
--- a/build-tools/pom.xml
+++ b/build-tools/pom.xml
@@ -23,7 +23,7 @@
     <modelVersion>4.0.0</modelVersion>
     <groupId>org.apache.falcon</groupId>
     <artifactId>build-tools</artifactId>
-    <version>0.4-SNAPSHOT</version>
+    <version>0.4-incubating-SNAPSHOT</version>
     <name>Build Tools</name>
 
     <build>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/client/pom.xml
----------------------------------------------------------------------
diff --git a/client/pom.xml b/client/pom.xml
index 9589528..45aff5b 100644
--- a/client/pom.xml
+++ b/client/pom.xml
@@ -25,7 +25,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-client</artifactId>
     <description>Apache Falcon CLI client</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/common/pom.xml
----------------------------------------------------------------------
diff --git a/common/pom.xml b/common/pom.xml
index 78fbba1..00d1f28 100644
--- a/common/pom.xml
+++ b/common/pom.xml
@@ -24,7 +24,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-common</artifactId>
     <description>Apache Falcon Common Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/docs/pom.xml
----------------------------------------------------------------------
diff --git a/docs/pom.xml b/docs/pom.xml
index d525580..5f038b1 100644
--- a/docs/pom.xml
+++ b/docs/pom.xml
@@ -22,7 +22,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-docs</artifactId>
     <description>Apache Falcon Documentation</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/feed/pom.xml
----------------------------------------------------------------------
diff --git a/feed/pom.xml b/feed/pom.xml
index 87e2c9a..27e17e7 100644
--- a/feed/pom.xml
+++ b/feed/pom.xml
@@ -25,7 +25,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-feed</artifactId>
     <description>Apache Falcon Feed Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/hadoop-webapp/pom.xml
----------------------------------------------------------------------
diff --git a/hadoop-webapp/pom.xml b/hadoop-webapp/pom.xml
index b6d719e..6c1e2ac 100644
--- a/hadoop-webapp/pom.xml
+++ b/hadoop-webapp/pom.xml
@@ -24,7 +24,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-hadoop-webapp</artifactId>
     <description>Apache Falcon Embedded Hadoop - Test Cluster</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/messaging/pom.xml
----------------------------------------------------------------------
diff --git a/messaging/pom.xml b/messaging/pom.xml
index 126b5ec..820734d 100644
--- a/messaging/pom.xml
+++ b/messaging/pom.xml
@@ -19,7 +19,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-messaging</artifactId>
     <description>Apache Falcon JMS messaging Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/metrics/pom.xml
----------------------------------------------------------------------
diff --git a/metrics/pom.xml b/metrics/pom.xml
index f77521c..9c38489 100644
--- a/metrics/pom.xml
+++ b/metrics/pom.xml
@@ -25,7 +25,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-metrics</artifactId>
     <description>Apache Falcon Metrics</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/oozie-el-extensions/pom.xml
----------------------------------------------------------------------
diff --git a/oozie-el-extensions/pom.xml b/oozie-el-extensions/pom.xml
index 20a1e26..8bd7da2 100644
--- a/oozie-el-extensions/pom.xml
+++ b/oozie-el-extensions/pom.xml
@@ -24,7 +24,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-oozie-el-extension</artifactId>
     <description>Apache Falcon Oozie EL Extension</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/oozie/pom.xml
----------------------------------------------------------------------
diff --git a/oozie/pom.xml b/oozie/pom.xml
index 7a3998a..a0499e3 100644
--- a/oozie/pom.xml
+++ b/oozie/pom.xml
@@ -24,7 +24,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-oozie-adaptor</artifactId>
     <description>Apache Falcon Oozie Adaptor Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index 0d4ff47..51d6451 100644
--- a/pom.xml
+++ b/pom.xml
@@ -19,7 +19,7 @@
     <modelVersion>4.0.0</modelVersion>
     <groupId>org.apache.falcon</groupId>
     <artifactId>falcon-main</artifactId>
-    <version>0.4-SNAPSHOT</version>
+    <version>0.4-incubating-SNAPSHOT</version>
     <description>Data Management and Processing Platform over Hadoop</description>
     <name>Apache Falcon</name>
     <packaging>pom</packaging>
@@ -844,7 +844,7 @@
                     <dependency>
                         <groupId>org.apache.falcon</groupId>
                         <artifactId>build-tools</artifactId>
-                        <version>0.4-SNAPSHOT</version>
+                        <version>0.4-incubating-SNAPSHOT</version>
                     </dependency>
                 </dependencies>
                 <executions>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/prism/pom.xml
----------------------------------------------------------------------
diff --git a/prism/pom.xml b/prism/pom.xml
index d0ace9a..561df89 100644
--- a/prism/pom.xml
+++ b/prism/pom.xml
@@ -24,7 +24,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-prism</artifactId>
     <description>Apache Falcon Prism</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/process/pom.xml
----------------------------------------------------------------------
diff --git a/process/pom.xml b/process/pom.xml
index 216008f..b024a70 100644
--- a/process/pom.xml
+++ b/process/pom.xml
@@ -18,7 +18,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-process</artifactId>
     <description>Apache Falcon Process Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/replication/pom.xml
----------------------------------------------------------------------
diff --git a/replication/pom.xml b/replication/pom.xml
index 5c805f8..83a4cca 100644
--- a/replication/pom.xml
+++ b/replication/pom.xml
@@ -25,7 +25,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-replication</artifactId>
     <description>Apache Falcon Replication Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/rerun/pom.xml
----------------------------------------------------------------------
diff --git a/rerun/pom.xml b/rerun/pom.xml
index 9b8ffa9..976775f 100644
--- a/rerun/pom.xml
+++ b/rerun/pom.xml
@@ -25,7 +25,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-rerun</artifactId>
     <description>Apache Falcon Rerun Handler</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/retention/pom.xml
----------------------------------------------------------------------
diff --git a/retention/pom.xml b/retention/pom.xml
index f572d49..8927013 100644
--- a/retention/pom.xml
+++ b/retention/pom.xml
@@ -25,7 +25,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-retention</artifactId>
     <description>Apache Falcon Retention Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/test-util/pom.xml
----------------------------------------------------------------------
diff --git a/test-util/pom.xml b/test-util/pom.xml
index e37f15c..9ebc056 100644
--- a/test-util/pom.xml
+++ b/test-util/pom.xml
@@ -25,7 +25,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-test-util</artifactId>
     <description>Apache Falcon Test Utility</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/24edc18b/webapp/pom.xml
----------------------------------------------------------------------
diff --git a/webapp/pom.xml b/webapp/pom.xml
index 0caa96c..db45ae7 100644
--- a/webapp/pom.xml
+++ b/webapp/pom.xml
@@ -24,7 +24,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.4-SNAPSHOT</version>
+        <version>0.4-incubating-SNAPSHOT</version>
     </parent>
     <artifactId>falcon-webapp</artifactId>
     <description>Apache Falcon Web Application</description>


[4/8] git commit: FALCON-55 Update suspends old oozie coords. Contributed by Shwetha GS

Posted by sr...@apache.org.
FALCON-55 Update suspends old oozie coords. Contributed by Shwetha GS


Project: http://git-wip-us.apache.org/repos/asf/incubator-falcon/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-falcon/commit/9d273658
Tree: http://git-wip-us.apache.org/repos/asf/incubator-falcon/tree/9d273658
Diff: http://git-wip-us.apache.org/repos/asf/incubator-falcon/diff/9d273658

Branch: refs/heads/v0.3
Commit: 9d2736589d2d93758774a9f81d70e9266a4d582e
Parents: 54d827f
Author: srikanth.sundarrajan <sr...@inmobi.com>
Authored: Mon Jul 22 19:13:11 2013 +0530
Committer: srikanth.sundarrajan <sr...@inmobi.com>
Committed: Mon Jul 22 19:13:11 2013 +0530

----------------------------------------------------------------------
 CHANGES.txt                                     |  6 +++
 .../workflow/engine/OozieWorkflowEngine.java    | 27 ++++++------
 .../oozie/client/CustomOozieClientTest.java     | 38 -----------------
 .../falcon/resource/EntityManagerJerseyIT.java  | 44 ++++++++++++--------
 .../org/apache/falcon/resource/TestContext.java |  4 ++
 5 files changed, 50 insertions(+), 69 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/9d273658/CHANGES.txt
----------------------------------------------------------------------
diff --git a/CHANGES.txt b/CHANGES.txt
index 4c655c8..d7e91ae 100755
--- a/CHANGES.txt
+++ b/CHANGES.txt
@@ -7,6 +7,12 @@ Release Version: 0.3
   NEW FEATURES
 
   IMPROVEMENTS
+   
+    FALCON-56 Update Falcon packing to include all source files. (Srikanth 
+    Sundarrajan)
+
+    FALCON-55 Update suspends old oozie coords. (Shwetha GS via Srikanth
+    Sundarrajan)
 
     FALCON-52 Main module configured used with jetty:run has issues with app 
     start. (Srikanth Sundarrajan)

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/9d273658/oozie/src/main/java/org/apache/falcon/workflow/engine/OozieWorkflowEngine.java
----------------------------------------------------------------------
diff --git a/oozie/src/main/java/org/apache/falcon/workflow/engine/OozieWorkflowEngine.java b/oozie/src/main/java/org/apache/falcon/workflow/engine/OozieWorkflowEngine.java
index fcb9d80..28a60c2 100644
--- a/oozie/src/main/java/org/apache/falcon/workflow/engine/OozieWorkflowEngine.java
+++ b/oozie/src/main/java/org/apache/falcon/workflow/engine/OozieWorkflowEngine.java
@@ -35,7 +35,7 @@ import org.apache.falcon.workflow.WorkflowBuilder;
 import org.apache.log4j.Logger;
 import org.apache.oozie.client.*;
 import org.apache.oozie.client.CoordinatorJob.Timeunit;
-import org.apache.oozie.client.WorkflowJob.Status;
+import org.apache.oozie.client.Job.Status;
 
 import java.util.*;
 import java.util.Map.Entry;
@@ -51,14 +51,14 @@ public class OozieWorkflowEngine extends AbstractWorkflowEngine {
     public static final String ENGINE = "oozie";
     private static final BundleJob MISSING = new NullBundleJob();
 
-    private static final List<Status> WF_KILL_PRECOND = Arrays.asList(Status.PREP,
-            Status.RUNNING, Status.SUSPENDED, Status.FAILED);
-    private static final List<Status> WF_SUSPEND_PRECOND = Arrays
-            .asList(Status.RUNNING);
-    private static final List<Status> WF_RESUME_PRECOND = Arrays
-            .asList(Status.SUSPENDED);
-    private static final List<Status> WF_RERUN_PRECOND = Arrays.asList(Status.FAILED,
-            Status.KILLED, Status.SUCCEEDED);
+    private static final List<WorkflowJob.Status> WF_KILL_PRECOND = Arrays.asList(WorkflowJob.Status.PREP,
+            WorkflowJob.Status.RUNNING, WorkflowJob.Status.SUSPENDED, WorkflowJob.Status.FAILED);
+    private static final List<WorkflowJob.Status> WF_SUSPEND_PRECOND = Arrays
+            .asList(WorkflowJob.Status.RUNNING);
+    private static final List<WorkflowJob.Status> WF_RESUME_PRECOND = Arrays
+            .asList(WorkflowJob.Status.SUSPENDED);
+    private static final List<WorkflowJob.Status> WF_RERUN_PRECOND = Arrays.asList(WorkflowJob.Status.FAILED,
+            WorkflowJob.Status.KILLED, WorkflowJob.Status.SUCCEEDED);
 
     private static final List<Job.Status> BUNDLE_ACTIVE_STATUS = Arrays.asList(
             Job.Status.PREP, Job.Status.RUNNING, Job.Status.SUSPENDED,
@@ -845,7 +845,7 @@ public class OozieWorkflowEngine extends AbstractWorkflowEngine {
             cal.setTime(coord.getLastActionTime());
             Frequency freq = createFrequency(coord.getFrequency(),
                     coord.getTimeUnit());
-            cal.add(freq.getTimeUnit().getCalendarUnit(), -1);
+            cal.add(freq.getTimeUnit().getCalendarUnit(), -freq.getFrequency());
             return cal.getTime();
         }
         return null;
@@ -906,6 +906,7 @@ public class OozieWorkflowEngine extends AbstractWorkflowEngine {
     }
 
     private void resume(String cluster, BundleJob bundle) throws FalconException {
+        bundle = getBundleInfo(cluster, bundle.getId());
         for (CoordinatorJob coord : bundle.getCoordinators()) {
             resume(cluster, coord.getId());
         }
@@ -1029,7 +1030,7 @@ public class OozieWorkflowEngine extends AbstractWorkflowEngine {
             jobprops.remove(OozieClient.COORDINATOR_APP_PATH);
             jobprops.remove(OozieClient.BUNDLE_APP_PATH);
             client.reRun(jobId, jobprops);
-            assertStatus(cluster, jobId, WorkflowJob.Status.RUNNING);
+            assertStatus(cluster, jobId, Job.Status.RUNNING);
             LOG.info("Rerun job " + jobId + " on cluster " + cluster);
         } catch (Exception e) {
             LOG.error("Unable to rerun workflows", e);
@@ -1119,7 +1120,7 @@ public class OozieWorkflowEngine extends AbstractWorkflowEngine {
         OozieClient client = OozieClientFactory.get(cluster);
         try {
             client.suspend(jobId);
-            assertStatus(cluster, jobId, Status.SUSPENDED, Status.SUCCEEDED,
+            assertStatus(cluster, jobId, Status.PREPSUSPENDED, Status.SUSPENDED, Status.SUCCEEDED,
                     Status.FAILED, Status.KILLED);
             LOG.info("Suspended job " + jobId + " on cluster " + cluster);
         } catch (OozieClientException e) {
@@ -1242,7 +1243,7 @@ public class OozieWorkflowEngine extends AbstractWorkflowEngine {
         try {
             WorkflowJob jobInfo = client.getJobInfo(jobId);
             instance.startTime = jobInfo.getStartTime();
-            if (jobInfo.getStatus() == Status.RUNNING) {
+            if (jobInfo.getStatus().name().equals(Status.RUNNING.name())) {
                 instance.endTime = new Date();
             } else {
                 instance.endTime = jobInfo.getEndTime();

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/9d273658/oozie/src/test/java/org/apache/oozie/client/CustomOozieClientTest.java
----------------------------------------------------------------------
diff --git a/oozie/src/test/java/org/apache/oozie/client/CustomOozieClientTest.java b/oozie/src/test/java/org/apache/oozie/client/CustomOozieClientTest.java
deleted file mode 100644
index cf0b385..0000000
--- a/oozie/src/test/java/org/apache/oozie/client/CustomOozieClientTest.java
+++ /dev/null
@@ -1,38 +0,0 @@
-/**
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.oozie.client;
-
-import org.testng.annotations.Test;
-
-import java.util.Properties;
-
-/**
- * Test to verify if the oozie client provided via CustomOozieClient is valid.
- */
-public class CustomOozieClientTest {
-
-    @Test(enabled = false)
-    public void testGetConfiguration() throws Exception {
-        CustomOozieClient client = new CustomOozieClient("http://localhost:11000/oozie");
-        Properties props = client.getConfiguration();
-        System.out.println(props);
-        props = client.getProperties();
-        System.out.println(props);
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/9d273658/webapp/src/test/java/org/apache/falcon/resource/EntityManagerJerseyIT.java
----------------------------------------------------------------------
diff --git a/webapp/src/test/java/org/apache/falcon/resource/TestContext.java b/webapp/src/test/java/org/apache/falcon/resource/TestContext.java
index 6fa07c9..a7ee75c 100644
--- a/webapp/src/test/java/org/apache/falcon/resource/TestContext.java
+++ b/webapp/src/test/java/org/apache/falcon/resource/TestContext.java
@@ -366,6 +366,10 @@ public class TestContext {
         return File.createTempFile("test", ".xml", target);
     }
 
+    public OozieClient getOozieClient() throws FalconException {
+        return OozieClientFactory.get(cluster.getCluster());
+    }
+
     public List<BundleJob> getBundles() throws Exception {
         List<BundleJob> bundles = new ArrayList<BundleJob>();
         if (clusterName == null) {


[6/8] git commit: FALCON-53 Add -incubating to the version. Contributed by Jarek Jarcec Cecho

Posted by sr...@apache.org.
FALCON-53 Add -incubating to the version. Contributed by Jarek Jarcec Cecho


Project: http://git-wip-us.apache.org/repos/asf/incubator-falcon/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-falcon/commit/812f6f79
Tree: http://git-wip-us.apache.org/repos/asf/incubator-falcon/tree/812f6f79
Diff: http://git-wip-us.apache.org/repos/asf/incubator-falcon/diff/812f6f79

Branch: refs/heads/v0.3
Commit: 812f6f7974b6fd6bb77de707f06fd2e235fa9092
Parents: 9d27365
Author: srikanth.sundarrajan <sr...@inmobi.com>
Authored: Mon Jul 22 19:16:43 2013 +0530
Committer: srikanth.sundarrajan <sr...@inmobi.com>
Committed: Mon Jul 22 19:16:43 2013 +0530

----------------------------------------------------------------------
 CHANGES.txt                 | 3 +++
 acquisition/pom.xml         | 2 +-
 archival/pom.xml            | 2 +-
 build-tools/pom.xml         | 2 +-
 client/pom.xml              | 2 +-
 common/pom.xml              | 2 +-
 docs/pom.xml                | 2 +-
 feed/pom.xml                | 2 +-
 hadoop-webapp/pom.xml       | 2 +-
 messaging/pom.xml           | 2 +-
 metrics/pom.xml             | 2 +-
 oozie-el-extensions/pom.xml | 2 +-
 oozie/pom.xml               | 2 +-
 pom.xml                     | 4 ++--
 prism/pom.xml               | 2 +-
 process/pom.xml             | 2 +-
 replication/pom.xml         | 2 +-
 rerun/pom.xml               | 2 +-
 retention/pom.xml           | 2 +-
 test-util/pom.xml           | 2 +-
 webapp/pom.xml              | 2 +-
 21 files changed, 24 insertions(+), 21 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/CHANGES.txt
----------------------------------------------------------------------
diff --git a/CHANGES.txt b/CHANGES.txt
index d7e91ae..8f75c6d 100755
--- a/CHANGES.txt
+++ b/CHANGES.txt
@@ -8,6 +8,9 @@ Release Version: 0.3
 
   IMPROVEMENTS
    
+    FALCON-53 Add -incubating to the version. (Jarek Jarcec Cecho via Srikanth
+    Sundarrajan)
+
     FALCON-56 Update Falcon packing to include all source files. (Srikanth 
     Sundarrajan)
 

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/acquisition/pom.xml
----------------------------------------------------------------------
diff --git a/acquisition/pom.xml b/acquisition/pom.xml
index 87055f4..ecaeabb 100644
--- a/acquisition/pom.xml
+++ b/acquisition/pom.xml
@@ -24,7 +24,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-acquisition</artifactId>
     <description>Apache Falcon Acquisition Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/archival/pom.xml
----------------------------------------------------------------------
diff --git a/archival/pom.xml b/archival/pom.xml
index 461fa44..cc1dbbd 100644
--- a/archival/pom.xml
+++ b/archival/pom.xml
@@ -24,7 +24,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-archival</artifactId>
     <description>Apache Falcon Archival Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/build-tools/pom.xml
----------------------------------------------------------------------
diff --git a/build-tools/pom.xml b/build-tools/pom.xml
index 703930e..231d43d 100644
--- a/build-tools/pom.xml
+++ b/build-tools/pom.xml
@@ -23,7 +23,7 @@
     <modelVersion>4.0.0</modelVersion>
     <groupId>org.apache.falcon</groupId>
     <artifactId>build-tools</artifactId>
-    <version>0.3</version>
+    <version>0.3-incubating</version>
     <name>Build Tools</name>
 
     <build>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/client/pom.xml
----------------------------------------------------------------------
diff --git a/client/pom.xml b/client/pom.xml
index c63bd78..a281819 100644
--- a/client/pom.xml
+++ b/client/pom.xml
@@ -25,7 +25,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-client</artifactId>
     <description>Apache Falcon CLI client</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/common/pom.xml
----------------------------------------------------------------------
diff --git a/common/pom.xml b/common/pom.xml
index f36561e..1a319f6 100644
--- a/common/pom.xml
+++ b/common/pom.xml
@@ -24,7 +24,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-common</artifactId>
     <description>Apache Falcon Common Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/docs/pom.xml
----------------------------------------------------------------------
diff --git a/docs/pom.xml b/docs/pom.xml
index b3a0d6d..6d1bcc5 100644
--- a/docs/pom.xml
+++ b/docs/pom.xml
@@ -22,7 +22,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-docs</artifactId>
     <description>Apache Falcon Documentation</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/feed/pom.xml
----------------------------------------------------------------------
diff --git a/feed/pom.xml b/feed/pom.xml
index 59b8f67..16101bf 100644
--- a/feed/pom.xml
+++ b/feed/pom.xml
@@ -25,7 +25,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-feed</artifactId>
     <description>Apache Falcon Feed Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/hadoop-webapp/pom.xml
----------------------------------------------------------------------
diff --git a/hadoop-webapp/pom.xml b/hadoop-webapp/pom.xml
index 2588ac7..112871f 100644
--- a/hadoop-webapp/pom.xml
+++ b/hadoop-webapp/pom.xml
@@ -24,7 +24,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-hadoop-webapp</artifactId>
     <description>Apache Falcon Embedded Hadoop - Test Cluster</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/messaging/pom.xml
----------------------------------------------------------------------
diff --git a/messaging/pom.xml b/messaging/pom.xml
index 87b1594..bf20594 100644
--- a/messaging/pom.xml
+++ b/messaging/pom.xml
@@ -19,7 +19,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-messaging</artifactId>
     <description>Apache Falcon JMS messaging Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/metrics/pom.xml
----------------------------------------------------------------------
diff --git a/metrics/pom.xml b/metrics/pom.xml
index 009eb73..d8853e7 100644
--- a/metrics/pom.xml
+++ b/metrics/pom.xml
@@ -25,7 +25,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-metrics</artifactId>
     <description>Apache Falcon Metrics</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/oozie-el-extensions/pom.xml
----------------------------------------------------------------------
diff --git a/oozie-el-extensions/pom.xml b/oozie-el-extensions/pom.xml
index 97b8c2f..f306bc9 100644
--- a/oozie-el-extensions/pom.xml
+++ b/oozie-el-extensions/pom.xml
@@ -24,7 +24,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-oozie-el-extension</artifactId>
     <description>Apache Falcon Oozie EL Extension</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/oozie/pom.xml
----------------------------------------------------------------------
diff --git a/oozie/pom.xml b/oozie/pom.xml
index 8a7acab..c682360 100644
--- a/oozie/pom.xml
+++ b/oozie/pom.xml
@@ -24,7 +24,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-oozie-adaptor</artifactId>
     <description>Apache Falcon Oozie Adaptor Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index 51b1eef..8fbce7b 100644
--- a/pom.xml
+++ b/pom.xml
@@ -19,7 +19,7 @@
     <modelVersion>4.0.0</modelVersion>
     <groupId>org.apache.falcon</groupId>
     <artifactId>falcon-main</artifactId>
-    <version>0.3</version>
+    <version>0.3-incubating</version>
     <description>Data Management and Processing Platform over Hadoop</description>
     <name>Apache Falcon</name>
     <packaging>pom</packaging>
@@ -844,7 +844,7 @@
                     <dependency>
                         <groupId>org.apache.falcon</groupId>
                         <artifactId>build-tools</artifactId>
-                        <version>0.3</version>
+                        <version>0.3-incubating</version>
                     </dependency>
                 </dependencies>
                 <executions>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/prism/pom.xml
----------------------------------------------------------------------
diff --git a/prism/pom.xml b/prism/pom.xml
index a3acbfd..aa56ab8 100644
--- a/prism/pom.xml
+++ b/prism/pom.xml
@@ -24,7 +24,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-prism</artifactId>
     <description>Apache Falcon Prism</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/process/pom.xml
----------------------------------------------------------------------
diff --git a/process/pom.xml b/process/pom.xml
index 78f6284..919ab0a 100644
--- a/process/pom.xml
+++ b/process/pom.xml
@@ -18,7 +18,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-process</artifactId>
     <description>Apache Falcon Process Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/replication/pom.xml
----------------------------------------------------------------------
diff --git a/replication/pom.xml b/replication/pom.xml
index f6f688a..9c1c139 100644
--- a/replication/pom.xml
+++ b/replication/pom.xml
@@ -25,7 +25,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-replication</artifactId>
     <description>Apache Falcon Replication Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/rerun/pom.xml
----------------------------------------------------------------------
diff --git a/rerun/pom.xml b/rerun/pom.xml
index 75f08cb..f511c6e 100644
--- a/rerun/pom.xml
+++ b/rerun/pom.xml
@@ -25,7 +25,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-rerun</artifactId>
     <description>Apache Falcon Rerun Handler</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/retention/pom.xml
----------------------------------------------------------------------
diff --git a/retention/pom.xml b/retention/pom.xml
index 0c51416..8fdd58c 100644
--- a/retention/pom.xml
+++ b/retention/pom.xml
@@ -25,7 +25,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-retention</artifactId>
     <description>Apache Falcon Retention Module</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/test-util/pom.xml
----------------------------------------------------------------------
diff --git a/test-util/pom.xml b/test-util/pom.xml
index 8a100f6..f01e804 100644
--- a/test-util/pom.xml
+++ b/test-util/pom.xml
@@ -25,7 +25,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-test-util</artifactId>
     <description>Apache Falcon Test Utility</description>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/812f6f79/webapp/pom.xml
----------------------------------------------------------------------
diff --git a/webapp/pom.xml b/webapp/pom.xml
index 8a6a1eb..72f6ed1 100644
--- a/webapp/pom.xml
+++ b/webapp/pom.xml
@@ -24,7 +24,7 @@
     <parent>
         <groupId>org.apache.falcon</groupId>
         <artifactId>falcon-main</artifactId>
-        <version>0.3</version>
+        <version>0.3-incubating</version>
     </parent>
     <artifactId>falcon-webapp</artifactId>
     <description>Apache Falcon Web Application</description>


[2/8] git commit: FALCON-56 Update Falcon packing to include all source files. Contributed by Srikanth Sundarrajan

Posted by sr...@apache.org.
FALCON-56 Update Falcon packing to include all source files. Contributed by Srikanth Sundarrajan


Project: http://git-wip-us.apache.org/repos/asf/incubator-falcon/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-falcon/commit/39eb9562
Tree: http://git-wip-us.apache.org/repos/asf/incubator-falcon/tree/39eb9562
Diff: http://git-wip-us.apache.org/repos/asf/incubator-falcon/diff/39eb9562

Branch: refs/heads/master
Commit: 39eb956236f6e46b407299490eb720b154b7d506
Parents: caa0d26
Author: srikanth.sundarrajan <sr...@inmobi.com>
Authored: Mon Jul 22 19:06:21 2013 +0530
Committer: srikanth.sundarrajan <sr...@inmobi.com>
Committed: Mon Jul 22 19:06:21 2013 +0530

----------------------------------------------------------------------
 pom.xml                             |  1 +
 src/main/assemblies/package.xml     | 18 +--------------
 src/main/assemblies/src-package.xml | 38 ++++++++++++++++++++++++++++++++
 3 files changed, 40 insertions(+), 17 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/39eb9562/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index 5776c30..0d4ff47 100644
--- a/pom.xml
+++ b/pom.xml
@@ -769,6 +769,7 @@
                 <configuration>
                     <descriptors>
                         <descriptor>src/main/assemblies/package.xml</descriptor>
+                        <descriptor>src/main/assemblies/src-package.xml</descriptor>
                     </descriptors>
                     <finalName>falcon-${project.version}</finalName>
                 </configuration>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/39eb9562/src/main/assemblies/package.xml
----------------------------------------------------------------------
diff --git a/src/main/assemblies/package.xml b/src/main/assemblies/package.xml
index fd600f2..b68692b 100644
--- a/src/main/assemblies/package.xml
+++ b/src/main/assemblies/package.xml
@@ -20,9 +20,9 @@
     xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
     xsi:schemaLocation="http://maven.apache.org/plugins/maven-assembly-plugin/assembly/1.1.2 http://maven.apache.org/xsd/assembly-1.1.2.xsd">
     <formats>
-        <format>dir</format>
         <format>tar.gz</format>
     </formats>
+    <id>bin</id>
     <fileSets>
         <fileSet>
             <directory>src/conf/</directory>
@@ -35,22 +35,6 @@
         </fileSet>
 
         <fileSet>
-            <directory>.</directory>
-            <outputDirectory>src</outputDirectory>
-            <includes>
-                <include>**/target/*sources.jar</include>
-            </includes>
-        </fileSet>
-
-        <fileSet>
-            <directory>.</directory>
-            <outputDirectory>docs</outputDirectory>
-            <includes>
-                <include>**/target/*javadoc.jar</include>
-            </includes>
-        </fileSet>
-
-        <fileSet>
             <directory>client/target/dependency</directory>
             <outputDirectory>client/lib</outputDirectory>
         </fileSet>

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/39eb9562/src/main/assemblies/src-package.xml
----------------------------------------------------------------------
diff --git a/src/main/assemblies/src-package.xml b/src/main/assemblies/src-package.xml
new file mode 100644
index 0000000..bdcf464
--- /dev/null
+++ b/src/main/assemblies/src-package.xml
@@ -0,0 +1,38 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!--
+  Licensed to the Apache Software Foundation (ASF) under one
+  or more contributor license agreements.  See the NOTICE file
+  distributed with this work for additional information
+  regarding copyright ownership.  The ASF licenses this file
+  to you under the Apache License, Version 2.0 (the
+  "License"); you may not use this file except in compliance
+  with the License.  You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+  Unless required by applicable law or agreed to in writing, software
+  distributed under the License is distributed on an "AS IS" BASIS,
+  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+  See the License for the specific language governing permissions and
+  limitations under the License.
+-->
+<assembly xmlns="http://maven.apache.org/plugins/maven-assembly-plugin/assembly/1.1.2"
+    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+    xsi:schemaLocation="http://maven.apache.org/plugins/maven-assembly-plugin/assembly/1.1.2 http://maven.apache.org/xsd/assembly-1.1.2.xsd">
+    <formats>
+        <format>tar.gz</format>
+    </formats>
+    <id>sources</id>
+    <fileSets>
+        <fileSet>
+            <directory>.</directory>
+            <excludes>
+                <exclude>**/target/**</exclude>
+                <exclude>**/logs/**</exclude>
+                <exclude>**/activemq-data/**</exclude>
+                <exclude>**/.git/**</exclude>
+            </excludes>
+        </fileSet>
+    </fileSets>
+</assembly>
+    


[8/8] git commit: FALCON-57 Build fails if the source is not in scm. Contributed by Srikanth Sundarrajan

Posted by sr...@apache.org.
FALCON-57 Build fails if the source is not in scm. Contributed by Srikanth Sundarrajan


Project: http://git-wip-us.apache.org/repos/asf/incubator-falcon/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-falcon/commit/9f3c4d9e
Tree: http://git-wip-us.apache.org/repos/asf/incubator-falcon/tree/9f3c4d9e
Diff: http://git-wip-us.apache.org/repos/asf/incubator-falcon/diff/9f3c4d9e

Branch: refs/heads/master
Commit: 9f3c4d9ecc4b27ec1322b1f610e31c39a0b32bb9
Parents: 24edc18
Author: srikanth.sundarrajan <sr...@inmobi.com>
Authored: Mon Jul 22 21:11:11 2013 +0530
Committer: srikanth.sundarrajan <sr...@inmobi.com>
Committed: Mon Jul 22 21:11:11 2013 +0530

----------------------------------------------------------------------
 CHANGES.txt | 2 ++
 pom.xml     | 1 +
 2 files changed, 3 insertions(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/9f3c4d9e/CHANGES.txt
----------------------------------------------------------------------
diff --git a/CHANGES.txt b/CHANGES.txt
index 234eee6..8a133bf 100755
--- a/CHANGES.txt
+++ b/CHANGES.txt
@@ -14,6 +14,8 @@ Trunk (Unreleased)
 
 Release Version: 0.3
 
+    FALCON-57 Build fails if the source is not in scm. (Srikanth Sundarrajan)
+
     FALCON-53 Add -incubating to the version. (Jarek Jarcec Cecho via Srikanth
     Sundarrajan)
 

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/9f3c4d9e/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index 51d6451..6986bd2 100644
--- a/pom.xml
+++ b/pom.xml
@@ -717,6 +717,7 @@
                     </execution>
                 </executions>
                 <configuration>
+                    <revisionOnScmFailure>release</revisionOnScmFailure>
                     <doCheck>false</doCheck>
                     <doUpdate>false</doUpdate>
                 </configuration>


[3/8] git commit: FALCON-55 Update suspends old oozie coords. Contributed by Shwetha GS

Posted by sr...@apache.org.
FALCON-55 Update suspends old oozie coords. Contributed by Shwetha GS


Project: http://git-wip-us.apache.org/repos/asf/incubator-falcon/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-falcon/commit/30102983
Tree: http://git-wip-us.apache.org/repos/asf/incubator-falcon/tree/30102983
Diff: http://git-wip-us.apache.org/repos/asf/incubator-falcon/diff/30102983

Branch: refs/heads/master
Commit: 30102983296baecb412b2f81672dbce6c9e8522b
Parents: 39eb956
Author: srikanth.sundarrajan <sr...@inmobi.com>
Authored: Mon Jul 22 19:11:34 2013 +0530
Committer: srikanth.sundarrajan <sr...@inmobi.com>
Committed: Mon Jul 22 19:11:34 2013 +0530

----------------------------------------------------------------------
 CHANGES.txt                                     |  6 +++
 .../workflow/engine/OozieWorkflowEngine.java    | 27 ++++++------
 .../oozie/client/CustomOozieClientTest.java     | 38 -----------------
 .../falcon/resource/EntityManagerJerseyIT.java  | 44 ++++++++++++--------
 .../org/apache/falcon/resource/TestContext.java |  4 ++
 5 files changed, 50 insertions(+), 69 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/30102983/CHANGES.txt
----------------------------------------------------------------------
diff --git a/CHANGES.txt b/CHANGES.txt
index cc7a019..33cc31f 100755
--- a/CHANGES.txt
+++ b/CHANGES.txt
@@ -14,6 +14,12 @@ Trunk (Unreleased)
 
 Release Version: 0.3
 
+    FALCON-56 Update Falcon packing to include all source files. (Srikanth
+    Sundarrajan)
+
+    FALCON-55 Update suspends old oozie coords. (Shwetha GS via Srikanth 
+    Sundarrajan)
+
     FALCON-52 Main module configured used with jetty:run has issues with app 
     start. (Srikanth Sundarrajan)
 

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/30102983/oozie/src/main/java/org/apache/falcon/workflow/engine/OozieWorkflowEngine.java
----------------------------------------------------------------------
diff --git a/oozie/src/main/java/org/apache/falcon/workflow/engine/OozieWorkflowEngine.java b/oozie/src/main/java/org/apache/falcon/workflow/engine/OozieWorkflowEngine.java
index fcb9d80..28a60c2 100644
--- a/oozie/src/main/java/org/apache/falcon/workflow/engine/OozieWorkflowEngine.java
+++ b/oozie/src/main/java/org/apache/falcon/workflow/engine/OozieWorkflowEngine.java
@@ -35,7 +35,7 @@ import org.apache.falcon.workflow.WorkflowBuilder;
 import org.apache.log4j.Logger;
 import org.apache.oozie.client.*;
 import org.apache.oozie.client.CoordinatorJob.Timeunit;
-import org.apache.oozie.client.WorkflowJob.Status;
+import org.apache.oozie.client.Job.Status;
 
 import java.util.*;
 import java.util.Map.Entry;
@@ -51,14 +51,14 @@ public class OozieWorkflowEngine extends AbstractWorkflowEngine {
     public static final String ENGINE = "oozie";
     private static final BundleJob MISSING = new NullBundleJob();
 
-    private static final List<Status> WF_KILL_PRECOND = Arrays.asList(Status.PREP,
-            Status.RUNNING, Status.SUSPENDED, Status.FAILED);
-    private static final List<Status> WF_SUSPEND_PRECOND = Arrays
-            .asList(Status.RUNNING);
-    private static final List<Status> WF_RESUME_PRECOND = Arrays
-            .asList(Status.SUSPENDED);
-    private static final List<Status> WF_RERUN_PRECOND = Arrays.asList(Status.FAILED,
-            Status.KILLED, Status.SUCCEEDED);
+    private static final List<WorkflowJob.Status> WF_KILL_PRECOND = Arrays.asList(WorkflowJob.Status.PREP,
+            WorkflowJob.Status.RUNNING, WorkflowJob.Status.SUSPENDED, WorkflowJob.Status.FAILED);
+    private static final List<WorkflowJob.Status> WF_SUSPEND_PRECOND = Arrays
+            .asList(WorkflowJob.Status.RUNNING);
+    private static final List<WorkflowJob.Status> WF_RESUME_PRECOND = Arrays
+            .asList(WorkflowJob.Status.SUSPENDED);
+    private static final List<WorkflowJob.Status> WF_RERUN_PRECOND = Arrays.asList(WorkflowJob.Status.FAILED,
+            WorkflowJob.Status.KILLED, WorkflowJob.Status.SUCCEEDED);
 
     private static final List<Job.Status> BUNDLE_ACTIVE_STATUS = Arrays.asList(
             Job.Status.PREP, Job.Status.RUNNING, Job.Status.SUSPENDED,
@@ -845,7 +845,7 @@ public class OozieWorkflowEngine extends AbstractWorkflowEngine {
             cal.setTime(coord.getLastActionTime());
             Frequency freq = createFrequency(coord.getFrequency(),
                     coord.getTimeUnit());
-            cal.add(freq.getTimeUnit().getCalendarUnit(), -1);
+            cal.add(freq.getTimeUnit().getCalendarUnit(), -freq.getFrequency());
             return cal.getTime();
         }
         return null;
@@ -906,6 +906,7 @@ public class OozieWorkflowEngine extends AbstractWorkflowEngine {
     }
 
     private void resume(String cluster, BundleJob bundle) throws FalconException {
+        bundle = getBundleInfo(cluster, bundle.getId());
         for (CoordinatorJob coord : bundle.getCoordinators()) {
             resume(cluster, coord.getId());
         }
@@ -1029,7 +1030,7 @@ public class OozieWorkflowEngine extends AbstractWorkflowEngine {
             jobprops.remove(OozieClient.COORDINATOR_APP_PATH);
             jobprops.remove(OozieClient.BUNDLE_APP_PATH);
             client.reRun(jobId, jobprops);
-            assertStatus(cluster, jobId, WorkflowJob.Status.RUNNING);
+            assertStatus(cluster, jobId, Job.Status.RUNNING);
             LOG.info("Rerun job " + jobId + " on cluster " + cluster);
         } catch (Exception e) {
             LOG.error("Unable to rerun workflows", e);
@@ -1119,7 +1120,7 @@ public class OozieWorkflowEngine extends AbstractWorkflowEngine {
         OozieClient client = OozieClientFactory.get(cluster);
         try {
             client.suspend(jobId);
-            assertStatus(cluster, jobId, Status.SUSPENDED, Status.SUCCEEDED,
+            assertStatus(cluster, jobId, Status.PREPSUSPENDED, Status.SUSPENDED, Status.SUCCEEDED,
                     Status.FAILED, Status.KILLED);
             LOG.info("Suspended job " + jobId + " on cluster " + cluster);
         } catch (OozieClientException e) {
@@ -1242,7 +1243,7 @@ public class OozieWorkflowEngine extends AbstractWorkflowEngine {
         try {
             WorkflowJob jobInfo = client.getJobInfo(jobId);
             instance.startTime = jobInfo.getStartTime();
-            if (jobInfo.getStatus() == Status.RUNNING) {
+            if (jobInfo.getStatus().name().equals(Status.RUNNING.name())) {
                 instance.endTime = new Date();
             } else {
                 instance.endTime = jobInfo.getEndTime();

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/30102983/oozie/src/test/java/org/apache/oozie/client/CustomOozieClientTest.java
----------------------------------------------------------------------
diff --git a/oozie/src/test/java/org/apache/oozie/client/CustomOozieClientTest.java b/oozie/src/test/java/org/apache/oozie/client/CustomOozieClientTest.java
deleted file mode 100644
index cf0b385..0000000
--- a/oozie/src/test/java/org/apache/oozie/client/CustomOozieClientTest.java
+++ /dev/null
@@ -1,38 +0,0 @@
-/**
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.oozie.client;
-
-import org.testng.annotations.Test;
-
-import java.util.Properties;
-
-/**
- * Test to verify if the oozie client provided via CustomOozieClient is valid.
- */
-public class CustomOozieClientTest {
-
-    @Test(enabled = false)
-    public void testGetConfiguration() throws Exception {
-        CustomOozieClient client = new CustomOozieClient("http://localhost:11000/oozie");
-        Properties props = client.getConfiguration();
-        System.out.println(props);
-        props = client.getProperties();
-        System.out.println(props);
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/30102983/webapp/src/test/java/org/apache/falcon/resource/EntityManagerJerseyIT.java
----------------------------------------------------------------------
diff --git a/webapp/src/test/java/org/apache/falcon/resource/TestContext.java b/webapp/src/test/java/org/apache/falcon/resource/TestContext.java
index 6fa07c9..a7ee75c 100644
--- a/webapp/src/test/java/org/apache/falcon/resource/TestContext.java
+++ b/webapp/src/test/java/org/apache/falcon/resource/TestContext.java
@@ -366,6 +366,10 @@ public class TestContext {
         return File.createTempFile("test", ".xml", target);
     }
 
+    public OozieClient getOozieClient() throws FalconException {
+        return OozieClientFactory.get(cluster.getCluster());
+    }
+
     public List<BundleJob> getBundles() throws Exception {
         List<BundleJob> bundles = new ArrayList<BundleJob>();
         if (clusterName == null) {
diff --git a/webapp/src/test/java/org/apache/falcon/resource/EntityManagerJerseyIT.java b/webapp/src/test/java/org/apache/falcon/resource/EntityManagerJerseyIT.java
index b94cff0..803e7f6 100644
--- a/webapp/src/test/java/org/apache/falcon/resource/EntityManagerJerseyIT.java
+++ b/webapp/src/test/java/org/apache/falcon/resource/EntityManagerJerseyIT.java
@@ -17,7 +17,23 @@
  */
 package org.apache.falcon.resource;
 
-import com.sun.jersey.api.client.ClientResponse;
+import java.io.File;
+import java.io.InputStream;
+import java.io.StringReader;
+import java.text.DateFormat;
+import java.text.SimpleDateFormat;
+import java.util.ArrayList;
+import java.util.Date;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.TimeZone;
+
+import javax.servlet.ServletInputStream;
+import javax.ws.rs.core.MediaType;
+import javax.ws.rs.core.Response;
+import javax.xml.bind.JAXBException;
+
 import org.apache.falcon.entity.v0.EntityType;
 import org.apache.falcon.entity.v0.feed.Feed;
 import org.apache.falcon.entity.v0.process.Input;
@@ -32,26 +48,13 @@ import org.apache.hadoop.fs.Path;
 import org.apache.oozie.client.BundleJob;
 import org.apache.oozie.client.Job;
 import org.apache.oozie.client.Job.Status;
+import org.apache.oozie.client.OozieClient;
 import org.testng.Assert;
 import org.testng.annotations.AfterMethod;
 import org.testng.annotations.BeforeClass;
 import org.testng.annotations.Test;
 
-import javax.servlet.ServletInputStream;
-import javax.ws.rs.core.MediaType;
-import javax.ws.rs.core.Response;
-import javax.xml.bind.JAXBException;
-import java.io.File;
-import java.io.InputStream;
-import java.io.StringReader;
-import java.text.DateFormat;
-import java.text.SimpleDateFormat;
-import java.util.ArrayList;
-import java.util.Date;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.TimeZone;
+import com.sun.jersey.api.client.ClientResponse;
 
 /**
  * Test class for Entity REST APIs.
@@ -186,6 +189,10 @@ public class EntityManagerJerseyIT {
         TestContext context = newContext();
         context.scheduleProcess();
         context.waitForBundleStart(Job.Status.RUNNING);
+        List<BundleJob> bundles = context.getBundles();
+        Assert.assertEquals(bundles.size(), 1);
+        OozieClient ozClient = context.getOozieClient();
+        String coordId = ozClient.getBundleJobInfo(bundles.get(0).getId()).getCoordinators().get(0).getId();
 
         ClientResponse response = context.service.path("api/entities/definition/process/"
                 + context.processName).header(
@@ -218,9 +225,10 @@ public class EntityManagerJerseyIT {
                 .post(ClientResponse.class, context.getServletInputStream(tmpFile.getAbsolutePath()));
         context.assertSuccessful(response);
 
-        //Assert that update creates new bundle
-        List<BundleJob> bundles = context.getBundles();
+        //Assert that update creates new bundle and old coord is running
+        bundles = context.getBundles();
         Assert.assertEquals(bundles.size(), 2);
+        Assert.assertEquals(ozClient.getCoordJobInfo(coordId).getStatus(), Status.RUNNING);
     }
 
     @Test

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/9d273658/webapp/src/test/java/org/apache/falcon/resource/TestContext.java
----------------------------------------------------------------------
diff --git a/webapp/src/test/java/org/apache/falcon/resource/EntityManagerJerseyIT.java b/webapp/src/test/java/org/apache/falcon/resource/EntityManagerJerseyIT.java
index b94cff0..803e7f6 100644
--- a/webapp/src/test/java/org/apache/falcon/resource/EntityManagerJerseyIT.java
+++ b/webapp/src/test/java/org/apache/falcon/resource/EntityManagerJerseyIT.java
@@ -17,7 +17,23 @@
  */
 package org.apache.falcon.resource;
 
-import com.sun.jersey.api.client.ClientResponse;
+import java.io.File;
+import java.io.InputStream;
+import java.io.StringReader;
+import java.text.DateFormat;
+import java.text.SimpleDateFormat;
+import java.util.ArrayList;
+import java.util.Date;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.TimeZone;
+
+import javax.servlet.ServletInputStream;
+import javax.ws.rs.core.MediaType;
+import javax.ws.rs.core.Response;
+import javax.xml.bind.JAXBException;
+
 import org.apache.falcon.entity.v0.EntityType;
 import org.apache.falcon.entity.v0.feed.Feed;
 import org.apache.falcon.entity.v0.process.Input;
@@ -32,26 +48,13 @@ import org.apache.hadoop.fs.Path;
 import org.apache.oozie.client.BundleJob;
 import org.apache.oozie.client.Job;
 import org.apache.oozie.client.Job.Status;
+import org.apache.oozie.client.OozieClient;
 import org.testng.Assert;
 import org.testng.annotations.AfterMethod;
 import org.testng.annotations.BeforeClass;
 import org.testng.annotations.Test;
 
-import javax.servlet.ServletInputStream;
-import javax.ws.rs.core.MediaType;
-import javax.ws.rs.core.Response;
-import javax.xml.bind.JAXBException;
-import java.io.File;
-import java.io.InputStream;
-import java.io.StringReader;
-import java.text.DateFormat;
-import java.text.SimpleDateFormat;
-import java.util.ArrayList;
-import java.util.Date;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.TimeZone;
+import com.sun.jersey.api.client.ClientResponse;
 
 /**
  * Test class for Entity REST APIs.
@@ -186,6 +189,10 @@ public class EntityManagerJerseyIT {
         TestContext context = newContext();
         context.scheduleProcess();
         context.waitForBundleStart(Job.Status.RUNNING);
+        List<BundleJob> bundles = context.getBundles();
+        Assert.assertEquals(bundles.size(), 1);
+        OozieClient ozClient = context.getOozieClient();
+        String coordId = ozClient.getBundleJobInfo(bundles.get(0).getId()).getCoordinators().get(0).getId();
 
         ClientResponse response = context.service.path("api/entities/definition/process/"
                 + context.processName).header(
@@ -218,9 +225,10 @@ public class EntityManagerJerseyIT {
                 .post(ClientResponse.class, context.getServletInputStream(tmpFile.getAbsolutePath()));
         context.assertSuccessful(response);
 
-        //Assert that update creates new bundle
-        List<BundleJob> bundles = context.getBundles();
+        //Assert that update creates new bundle and old coord is running
+        bundles = context.getBundles();
         Assert.assertEquals(bundles.size(), 2);
+        Assert.assertEquals(ozClient.getCoordJobInfo(coordId).getStatus(), Status.RUNNING);
     }
 
     @Test

http://git-wip-us.apache.org/repos/asf/incubator-falcon/blob/30102983/webapp/src/test/java/org/apache/falcon/resource/TestContext.java
----------------------------------------------------------------------